@@ -14,10 +14,9 @@
  * limitations under the License.
  *
  */
-#include "CameraWindow.hh"
-
 #if __APPLE__
   #include <OpenGL/gl.h>
+  #include <OpenGL/OpenGL.h>
   #include <GLUT/glut.h>
 #else
   #include <GL/glew.h>
@@ -27,15 +26,17 @@
 
 #if !defined(__APPLE__) && !defined(_WIN32)
   #include <GL/glx.h>
+  #undef Status
 #endif
 
 #include <gazebo/common/Console.hh>
+#include <gazebo/transport/TransportIface.hh>
 
 #include <gz/rendering/Camera.hh>
 #include <gz/rendering/Image.hh>
 #include <gz/rendering/Scene.hh>
-#include <gz/rendering.hh>
 
+#include "CameraWindow.hh"
 #include "SceneManager.hh"
 
 #define KEY_ESC 27
@@ -49,11 +50,15 @@ std::vector<gz::rendering::CameraPtr> g_cameras;
 gz::rendering::CameraPtr g_camera;
 gz::rendering::CameraPtr g_currCamera;
 unsigned int g_cameraIndex = 0;
-gz::rendering::ImagePtr g_image;
+gz::ImagePtr g_image;
 
 bool g_initContext = false;
 
-#if not (__APPLE__ || _WIN32)
+#if __APPLE__
+  CGLContextObj g_context;
+  CGLContextObj g_glutContext;
+#elif _WIN32
+#else
   GLXContext g_context;
   Display *g_display;
   GLXDrawable g_drawable;
@@ -67,7 +72,10 @@ double g_offset = 0.0;
 //////////////////////////////////////////////////
 void GlutRun(std::vector<gz::rendering::CameraPtr> _cameras)
 {
-#if not (__APPLE__ || _WIN32)
+#if __APPLE__
+  g_context = CGLGetCurrentContext();
+#elif _WIN32
+#else
   g_context = glXGetCurrentContext();
   g_display = glXGetCurrentDisplay();
   g_drawable = glXGetCurrentDrawable();
@@ -78,7 +86,10 @@ void GlutRun(std::vector<gz::rendering::CameraPtr> _cameras)
   GlutInitContext();
   GlutPrintUsage();
 
-#if not (__APPLE__ || _WIN32)
+#if __APPLE__
+  g_glutContext = CGLGetCurrentContext();
+#elif _WIN32
+#else
   g_glutDisplay = glXGetCurrentDisplay();
   g_glutDrawable = glXGetCurrentDrawable();
   g_glutContext = glXGetCurrentContext();
@@ -90,7 +101,10 @@ void GlutRun(std::vector<gz::rendering::CameraPtr> _cameras)
 //////////////////////////////////////////////////
 void GlutDisplay()
 {
-#if not (__APPLE__ || _WIN32)
+#if __APPLE__
+  CGLSetCurrentContext(g_context);
+#elif _WIN32
+#else
   if (g_display)
   {
     glXMakeCurrent(g_display, g_drawable, g_context);
@@ -99,7 +113,10 @@ void GlutDisplay()
 
   g_cameras[g_cameraIndex]->Capture(*g_image);
 
-#if not (__APPLE__ || _WIN32)
+#if __APPLE__
+  CGLSetCurrentContext(g_glutContext);
+#elif _WIN32
+#else
   glXMakeCurrent(g_glutDisplay, g_glutDrawable, g_glutContext);
 #endif
 
@@ -117,7 +134,10 @@ void GlutDisplay()
 //////////////////////////////////////////////////
 void GlutIdle()
 {
-#if not (__APPLE__ || _WIN32)
+#if __APPLE__
+  CGLSetCurrentContext(g_context);
+#elif _WIN32
+#else
   if (g_display)
   {
     glXMakeCurrent(g_display, g_drawable, g_context);
@@ -129,7 +149,10 @@ void GlutIdle()
 
   manager->UpdateScenes();
 
-#if not (__APPLE__ || _WIN32)
+#if __APPLE__
+  CGLSetCurrentContext(g_glutContext);
+#elif _WIN32
+#else
   glXMakeCurrent(g_glutDisplay, g_glutDrawable, g_glutContext);
 #endif
 
@@ -141,6 +164,9 @@ void GlutKeyboard(unsigned char _key, int, int)
 {
   if (_key == KEY_ESC || _key == 'q' || _key == 'Q')
   {
+    // stop transport
+    gazebo::transport::stop();
+    gazebo::transport::fini();
     exit(0);
   }
   else if (_key == KEY_TAB)
@@ -168,9 +194,6 @@ void GlutInitCamera(gz::rendering::CameraPtr _camera)
 //////////////////////////////////////////////////
 void GlutInitContext()
 {
-  int argc = 0;
-  char **argv = 0;
-  glutInit(&argc, argv);
   glutInitDisplayMode(GLUT_DOUBLE);
   glutInitWindowPosition(0, 0);
   glutInitWindowSize(imgw, imgh);
