@@ -279,12 +279,6 @@ void displayCB()
   glDrawPixels(imgw, imgh, GL_RGB, GL_UNSIGNED_BYTE, data);
 
   glutSwapBuffers();
-
-  // Uncomment to print FPS
-  // static gz::common::Time previous;
-  // auto now = gz::common::Time::SystemTime();
-  // std::cerr << (now - previous).Double() << std::endl;
-  // previous = now;
 }
 
 //////////////////////////////////////////////////
@@ -316,6 +310,14 @@ void keyboardCB(unsigned char _key, int, int)
       }
     }
   }
+  else if (_key == 's')
+  {
+    // toggle sky
+    for (ir::CameraPtr camera : g_cameras)
+    {
+      camera->Scene()->SetSkyEnabled(!camera->Scene()->SkyEnabled());
+    }
+  }
 }
 
 //////////////////////////////////////////////////
@@ -351,6 +353,7 @@ void printUsage()
   std::cout << "  TAB - Switch render engines  " << std::endl;
   std::cout << "  ESC - Exit                   " << std::endl;
   std::cout << "  P   - Toggle render pass     " << std::endl;
+  std::cout << "  S   - Toggle skybox          " << std::endl;
   std::cout << "===============================" << std::endl;
 }
 
@@ -388,5 +391,3 @@ void run(std::vector<ir::CameraPtr> _cameras)
 
   glutMainLoop();
 }
-
-
