@@ -113,6 +113,9 @@ void OgreDepthCamera::Destroy()
   if (!this->ogreCamera || !this->scene->IsInitialized())
     return;
 
+  this->DestroyPointCloudTexture();
+  this->DestroyDepthTexture();
+
   Ogre::SceneManager *ogreSceneManager;
   ogreSceneManager = this->scene->OgreSceneManager();
   if (ogreSceneManager == nullptr)
@@ -127,6 +130,9 @@ void OgreDepthCamera::Destroy()
       this->ogreCamera = nullptr;
     }
   }
+
+  // call base node destroy to remove parent
+  OgreNode::Destroy();
 }
 
 //////////////////////////////////////////////////
@@ -223,6 +229,24 @@ void OgreDepthCamera::CreatePointCloudTexture()
   this->dataPtr->pcdTexture->PreRender();
 }
 
+//////////////////////////////////////////////////
+void OgreDepthCamera::DestroyPointCloudTexture()
+{
+  if (this->dataPtr->pcdTexture)
+  {
+    dynamic_cast<OgreRenderTexture *>(this->dataPtr->pcdTexture.get())
+      ->Destroy();
+    this->dataPtr->pcdTexture.reset();
+  }
+
+  if (this->dataPtr->colorTexture)
+  {
+    dynamic_cast<OgreRenderTexture *>(this->dataPtr->colorTexture.get())
+      ->Destroy();
+    this->dataPtr->colorTexture.reset();
+  }
+}
+
 /////////////////////////////////////////////////
 void OgreDepthCamera::CreateDepthTexture()
 {
@@ -253,6 +277,16 @@ void OgreDepthCamera::CreateDepthTexture()
   this->ogreCamera->setFOVy(Ogre::Radian(this->LimitFOV(vfov)));
 }
 
+//////////////////////////////////////////////////
+void OgreDepthCamera::DestroyDepthTexture()
+{
+  if (this->depthTexture)
+  {
+    dynamic_cast<OgreRenderTexture *>(this->depthTexture.get())->Destroy();
+    this->depthTexture.reset();
+  }
+}
+
 //////////////////////////////////////////////////
 void OgreDepthCamera::PreRender()
 {
