@@ -17,20 +17,21 @@
 
 // Note this include is placed in the src file because
 // otherwise ogre produces compile errors
-#ifdef _MSC_VER
-#pragma warning(push, 0)
+#if defined(_MSC_VER)
+#pragma warning(push)
+#pragma warning(disable: 5033)
 #endif
 #include <Hlms/Pbs/OgreHlmsPbsDatablock.h>
-#ifdef _MSC_VER
+#if defined(_MSC_VER)
 #pragma warning(pop)
 #endif
 
-#include "ignition/common/Console.hh"
-#include "ignition/rendering/ogre2/Ogre2Conversions.hh"
-#include "ignition/rendering/ogre2/Ogre2DynamicRenderable.hh"
-#include "ignition/rendering/ogre2/Ogre2Material.hh"
-#include "ignition/rendering/ogre2/Ogre2RenderEngine.hh"
-#include "ignition/rendering/ogre2/Ogre2Scene.hh"
+#include "gz/common/Console.hh"
+#include "gz/rendering/ogre2/Ogre2Conversions.hh"
+#include "gz/rendering/ogre2/Ogre2DynamicRenderable.hh"
+#include "gz/rendering/ogre2/Ogre2Material.hh"
+#include "gz/rendering/ogre2/Ogre2RenderEngine.hh"
+#include "gz/rendering/ogre2/Ogre2Scene.hh"
 
 #ifdef _MSC_VER
   #pragma warning(push, 0)
@@ -40,18 +41,19 @@
 #include <OgreMeshManager2.h>
 #include <OgreSceneManager.h>
 #include <OgreSubMesh2.h>
+#include <Vao/OgreVaoManager.h>
 #ifdef _MSC_VER
   #pragma warning(pop)
 #endif
 
 /// \brief Private implementation
-class ignition::rendering::Ogre2DynamicRenderablePrivate
+class gz::rendering::Ogre2DynamicRenderablePrivate
 {
   /// \brief list of colors at each point
-  public: std::vector<ignition::math::Color> colors;
+  public: std::vector<gz::math::Color> colors;
 
   /// \brief List of vertices for the mesh
-  public: std::vector<ignition::math::Vector3d> vertices;
+  public: std::vector<gz::math::Vector3d> vertices;
 
   /// \brief Used to indicate if the lines require an update
   public: bool dirty = false;
@@ -92,7 +94,7 @@ class ignition::rendering::Ogre2DynamicRenderablePrivate
 };
 
 
-using namespace ignition;
+using namespace gz;
 using namespace rendering;
 
 //////////////////////////////////////////////////
@@ -130,6 +132,16 @@ void Ogre2DynamicRenderable::Destroy()
   this->dataPtr->sceneManager->destroyItem(this->dataPtr->ogreItem);
   this->dataPtr->ogreItem = nullptr;
 
+  // remove mesh from mesh manager
+  if (this->dataPtr->subMesh &&
+      Ogre::MeshManager::getSingleton().resourceExists(
+      this->dataPtr->subMesh->mParent->getName()))
+  {
+    Ogre::MeshManager::getSingleton().remove(
+        this->dataPtr->subMesh->mParent->getName());
+    this->dataPtr->subMesh = nullptr;
+  }
+
   if (this->dataPtr->material && this->dataPtr->ownsMaterial)
   {
     this->dataPtr->scene->DestroyMaterial(this->dataPtr->material);
@@ -150,11 +162,16 @@ void Ogre2DynamicRenderable::DestroyBuffer()
   if (!vaoManager)
     return;
 
-  if (this->dataPtr->vertexBuffer)
-    vaoManager->destroyVertexBuffer(this->dataPtr->vertexBuffer);
-
-  if (this->dataPtr->vao)
-    vaoManager->destroyVertexArrayObject(this->dataPtr->vao);
+  if (this->dataPtr->subMesh)
+  {
+    if (!this->dataPtr->subMesh->mVao[Ogre::VpNormal].empty())
+    {
+      this->dataPtr->subMesh->destroyVaos(
+          this->dataPtr->subMesh->mVao[Ogre::VpNormal], vaoManager);
+    }
+    if (!this->dataPtr->subMesh->mVao[Ogre::VpShadow].empty())
+      this->dataPtr->subMesh->mVao[Ogre::VpShadow].clear();
+  }
 
   this->dataPtr->vertexBuffer = nullptr;
   this->dataPtr->vao = nullptr;
@@ -326,6 +343,9 @@ void Ogre2DynamicRenderable::UpdateBuffer()
   // update item aabb
   if (this->dataPtr->ogreItem)
   {
+    bool castShadows = this->dataPtr->ogreItem->getCastShadows();
+    auto lowLevelMat = this->dataPtr->ogreItem->getSubItem(0)->getMaterial();
+
     // need to rebuild ogre [sub]item because the vao was destroyed
     // this updates the item's bounding box and fixes occasional crashes
     // from invalid access to old vao
@@ -340,6 +360,13 @@ void Ogre2DynamicRenderable::UpdateBuffer()
       this->dataPtr->ogreItem->setCastShadows(
           this->dataPtr->material->CastShadows());
     }
+    else if (lowLevelMat)
+    {
+      // the _initialise call above resets the ogre item properties so set
+      // them again
+      this->dataPtr->ogreItem->getSubItem(0)->setMaterial(lowLevelMat);
+      this->dataPtr->ogreItem->setCastShadows(castShadows);
+    }
   }
 
   this->dataPtr->dirty = false;
@@ -416,8 +443,8 @@ MarkerType Ogre2DynamicRenderable::OperationType() const
 }
 
 /////////////////////////////////////////////////
-void Ogre2DynamicRenderable::AddPoint(const ignition::math::Vector3d &_pt,
-                                      const ignition::math::Color &_color)
+void Ogre2DynamicRenderable::AddPoint(const math::Vector3d &_pt,
+                                      const math::Color &_color)
 {
   this->dataPtr->vertices.push_back(_pt);
 
@@ -432,14 +459,14 @@ void Ogre2DynamicRenderable::AddPoint(const ignition::math::Vector3d &_pt,
 
 /////////////////////////////////////////////////
 void Ogre2DynamicRenderable::AddPoint(double _x, double _y, double _z,
-                                      const ignition::math::Color &_color)
+                                      const math::Color &_color)
 {
-  this->AddPoint(ignition::math::Vector3d(_x, _y, _z), _color);
+  this->AddPoint(math::Vector3d(_x, _y, _z), _color);
 }
 
 /////////////////////////////////////////////////
 void Ogre2DynamicRenderable::SetPoint(unsigned int _index,
-                                      const ignition::math::Vector3d &_value)
+                                      const math::Vector3d &_value)
 {
   if (_index >= this->dataPtr->vertices.size())
   {
@@ -455,7 +482,7 @@ void Ogre2DynamicRenderable::SetPoint(unsigned int _index,
 
 /////////////////////////////////////////////////
 void Ogre2DynamicRenderable::SetColor(unsigned int _index,
-                                      const ignition::math::Color &_color)
+                                      const math::Color &_color)
 {
   if (_index >= this->dataPtr->colors.size())
   {
@@ -475,7 +502,7 @@ void Ogre2DynamicRenderable::SetColor(unsigned int _index,
 }
 
 /////////////////////////////////////////////////
-ignition::math::Vector3d Ogre2DynamicRenderable::Point(
+math::Vector3d Ogre2DynamicRenderable::Point(
     const unsigned int _index) const
 {
   if (_index >= this->dataPtr->vertices.size())
@@ -483,9 +510,9 @@ ignition::math::Vector3d Ogre2DynamicRenderable::Point(
     ignerr << "Point index[" << _index << "] is out of bounds[0-"
            << this->dataPtr->vertices.size()-1 << "]\n";
 
-    return ignition::math::Vector3d(ignition::math::INF_D,
-                                    ignition::math::INF_D,
-                                    ignition::math::INF_D);
+    return math::Vector3d(math::INF_D,
+                                    math::INF_D,
+                                    math::INF_D);
   }
 
   return this->dataPtr->vertices[_index];
