@@ -20,17 +20,30 @@
 #include "gz/rendering/ogre2/Ogre2Light.hh"
 
 #include "gz/rendering/ogre2/Ogre2Conversions.hh"
-#include "gz/rendering/ogre2/Ogre2Includes.hh"
 #include "gz/rendering/ogre2/Ogre2Scene.hh"
 
-using namespace gz;
+#ifdef _MSC_VER
+  #pragma warning(push, 0)
+#endif
+#include <OgreSceneManager.h>
+#ifdef _MSC_VER
+  #pragma warning(pop)
+#endif
+
+/// \brief Private data for the Ogre2Light class
+class gz::rendering::Ogre2LightPrivate
+{
+};
+
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
 // Ogre2Light
 //////////////////////////////////////////////////
 Ogre2Light::Ogre2Light() :
-  ogreLightType(Ogre::Light::LT_POINT)
+  ogreLightType(Ogre::Light::LT_POINT),
+  dataPtr(std::make_unique<Ogre2LightPrivate>())
 {
 }
 
@@ -117,6 +130,18 @@ void Ogre2Light::SetAttenuationRange(double _range)
   this->UpdateAttenuation();
 }
 
+//////////////////////////////////////////////////
+double Ogre2Light::Intensity() const
+{
+  return this->ogreLight->getPowerScale() / IGN_PI;
+}
+
+//////////////////////////////////////////////////
+void Ogre2Light::SetIntensity(double _intensity)
+{
+  this->ogreLight->setPowerScale(_intensity * IGN_PI);
+}
+
 //////////////////////////////////////////////////
 bool Ogre2Light::CastShadows() const
 {
