@@ -57,14 +57,10 @@ class MeshTest : public testing::Test,
 /////////////////////////////////////////////////
 void MeshTest::MeshSubMesh(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -127,14 +123,10 @@ void MeshTest::MeshSubMesh(const std::string &_renderEngine)
 /////////////////////////////////////////////////
 void MeshTest::MeshSkeleton(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -230,14 +222,10 @@ TEST_P(MeshTest, MeshSkeleton)
 /////////////////////////////////////////////////
 void MeshTest::MeshSkeletonAnimation(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                                                                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -330,14 +318,10 @@ TEST_P(MeshTest, MeshSkeletonAnimation)
 /////////////////////////////////////////////////
 void MeshTest::MeshClone(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                                                                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
            << "' is not supported" << std::endl;
     return;
   }
