@@ -17,15 +17,15 @@
 
 #include <gtest/gtest.h>
 
-#include <ignition/common/Console.hh>
+#include <gz/common/Console.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
-#include "ignition/rendering/RenderEngine.hh"
-#include "ignition/rendering/RenderTarget.hh"
-#include "ignition/rendering/RenderingIface.hh"
-#include "ignition/rendering/Scene.hh"
+#include "gz/rendering/RenderEngine.hh"
+#include "gz/rendering/RenderTarget.hh"
+#include "gz/rendering/RenderingIface.hh"
+#include "gz/rendering/Scene.hh"
 
-using namespace ignition;
+using namespace gz;
 using namespace rendering;
 
 class SceneTest : public testing::Test,
@@ -52,6 +52,10 @@ class SceneTest : public testing::Test,
   /// \brief Test creating and destroying materials
   public: void Materials(const std::string &_renderEngine);
 
+  public: const std::string TEST_MEDIA_PATH =
+        common::joinPaths(std::string(PROJECT_SOURCE_PATH),
+        "test", "media", "skeleton");
+
   /// \brief Test setting and getting Time
   public: void Time(const std::string &_renderEngine);
 
@@ -87,7 +91,7 @@ void SceneTest::Scene(const std::string &_renderEngine)
 
   // TODO(anyone) gradient background color and render window only supported
   // by ogre
-  if (_renderEngine == "ogre")
+  if (_renderEngine == "ogre2")
   {
     EXPECT_FALSE(scene->IsGradientBackgroundColor());
 
@@ -125,7 +129,7 @@ void SceneTest::Scene(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  rendering::unloadEngine(engine->Name());
+  unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -209,7 +213,7 @@ void SceneTest::Nodes(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  rendering::unloadEngine(engine->Name());
+  unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -311,7 +315,7 @@ void SceneTest::RemoveNodes(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  rendering::unloadEngine(engine->Name());
+  unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -456,11 +460,85 @@ void SceneTest::DestroyNodes(const std::string &_renderEngine)
   EXPECT_FALSE(scene->HasVisual(childB));
   EXPECT_FALSE(scene->HasVisual(childAA));
 
+  auto gizmoVisual = scene->CreateGizmoVisual("gizmo_visual");
+  auto planeVisual = scene->CreatePlane();
+  auto meshVisual = scene->CreateMesh(
+    common::joinPaths(TEST_MEDIA_PATH, "walk.dae"));
+
+  common::MeshPtr mesh(new common::Mesh());
+  meshVisual = scene->CreateMesh(mesh.get());
+
+  scene->DestroyVisuals();
+
+  common::Material mat(math::Color(1.0f, 0.5f, 0.2f, 1.0f));
+  auto materialVisual = scene->CreateMaterial(mat);
+  scene->DestroyMaterial(materialVisual);
+  scene->DestroyMaterial(MaterialPtr());
+
+  auto depthCameraSensor = scene->CreateDepthCamera();
+  scene->DestroySensors();
+  depthCameraSensor = scene->CreateDepthCamera("camera_depth");
+  scene->DestroySensorByName("camera_depth");
+  depthCameraSensor = scene->CreateDepthCamera("camera_depth");
+  EXPECT_FALSE(scene->HasSensor(ConstSensorPtr()));
+  EXPECT_FALSE(scene->HasSensorId(8));
+  EXPECT_FALSE(scene->HasSensorName("invalid"));
+  EXPECT_TRUE(scene->HasSensorName("camera_depth"));
+
+  auto dCSensor = scene->SensorByName("camera_depth");
+  EXPECT_TRUE(scene->HasSensor(dCSensor));
+  EXPECT_TRUE(scene->HasSensorName("camera_depth"));
+  scene->DestroySensor(dCSensor, false);
+
+  depthCameraSensor = scene->CreateDepthCamera(76);
+  dCSensor = scene->SensorById(76);
+  EXPECT_TRUE(scene->HasSensor(dCSensor));
+  EXPECT_TRUE(scene->HasSensorId(76));
+  scene->DestroySensor(dCSensor, true);
+
+  depthCameraSensor = scene->CreateDepthCamera(76);
+  scene->DestroySensorById(76);
+
+  depthCameraSensor = scene->CreateDepthCamera();
+  scene->DestroySensorByIndex(0);
+
+  // lights
+  auto spotLight = scene->CreateSpotLight();
+  auto pointLight = scene->CreatePointLight("point_light");
+  auto directionalLight = scene->CreateDirectionalLight(99);
+
+  auto directionalLight2 = scene->LightById(99);
+  EXPECT_EQ(directionalLight, directionalLight2);
+
+  auto directionalLight3 = scene->CreateDirectionalLight("directional_light");
+
+  auto pointLight2 = scene->LightByName("point_light");
+  EXPECT_EQ(pointLight, pointLight2);
+
+  scene->DestroyLightByIndex(0);
+  scene->DestroyLight(pointLight, true);
+  scene->DestroyLights();
+
+  spotLight = scene->CreateSpotLight();
+  scene->DestroyNodeByIndex(0);
+
+  spotLight = scene->CreateSpotLight("light_node");
+  scene->DestroyNodeByName("light_node");
+
+  spotLight = scene->CreateSpotLight(56);
+  scene->DestroyNodeById(56);
+
   EXPECT_EQ(0u, scene->VisualCount());
+  EXPECT_EQ(0u, scene->SensorCount());
+  EXPECT_EQ(0u, scene->LightCount());
+
+  EXPECT_EQ(std::chrono::milliseconds(0), scene->Time());
+  scene->SetTime(std::chrono::milliseconds(3550));
+  EXPECT_EQ(std::chrono::milliseconds(3550), scene->Time());
 
   // Clean up
   engine->DestroyScene(scene);
-  rendering::unloadEngine(engine->Name());
+  unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -526,7 +604,7 @@ void SceneTest::NodeCycle(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  rendering::unloadEngine(engine->Name());
+  unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -656,7 +734,7 @@ void SceneTest::Materials(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  rendering::unloadEngine(engine->Name());
+  unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -837,7 +915,7 @@ TEST_P(SceneTest, Sky)
 
 INSTANTIATE_TEST_CASE_P(Scene, SceneTest,
     RENDER_ENGINE_VALUES,
-    ignition::rendering::PrintToStringParam());
+    PrintToStringParam());
 
 int main(int argc, char **argv)
 {
