@@ -47,7 +47,7 @@ void UtilTest::ClickToScene(const std::string &_renderEngine)
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
            << "' is not supported" << std::endl;
     return;
   }
