@@ -23,7 +23,6 @@
 #include <gtest/gtest.h>
 
 #include <gz/common/Console.hh>
-#include <gz/utils/ExtraTestMacros.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
 
@@ -180,15 +179,13 @@ void SceneFactoryTest::VisualMemoryLeak(const std::string &_renderEngine)
 }
 
 /////////////////////////////////////////////////
-TEST_P(SceneFactoryTest,
-       IGN_UTILS_TEST_DISABLED_ON_WIN32(MaterialMemoryLeak))
+TEST_P(SceneFactoryTest, MaterialMemoryLeak)
 {
   MaterialMemoryLeak(GetParam());
 }
 
 /////////////////////////////////////////////////
-TEST_P(SceneFactoryTest,
-       IGN_UTILS_TEST_DISABLED_ON_WIN32(VisualMemoryLeak))
+TEST_P(SceneFactoryTest, VisualMemoryLeak)
 {
   VisualMemoryLeak(GetParam());
 }
